default_paths

Function default_paths 

pub fn default_paths() -> impl Iterator<Item = PathBuf>
Returns the default paths in which desktop entries should be searched for based on the current environment. Paths are sorted by priority.

Panics in case determining the current home directory fails.